update_progress — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

# update_progress

class `camelot.view.action_steps.update_progress.` `UpdateProgress`(value=0, maximum=0, text=None, detail=None, clear_details=False)

  Inform the user about the progress the application is making while executing an action. This ActionStep is not blocking. So it can be used inside transactions and will result in a minimum of delay when yielded. Each time an object is yielded, the progress dialog will be updated.

  Parameters: | value – the current step maximum – the maximum number of steps that will be executed. set it to 0 to display a busy indicator instead of a progres bar text – the text to be displayed inside the progres bar detail – the text to be displayed below the progres bar, this text is appended to the text already there clear_details – clear the details text already there before putting the new detail text.

  `gui_run`(gui_context)

    This method will update the progress dialog, if such dialog exists within the GuiContext

    Parameters: | gui_context – a `camelot.admin.action.GuiContext` instance

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

Comments
blog comments powered by Disqus